Defog.ai - AI Assistant for Data Analysis
Description: Train your AI data assistant on your own device

# Select Model

Locally Hosted (Community)
🦾 Model Type: `SQLCoder-7b-4_k.GGUF` ℹ
🆓 Free forever! ℹ
🤷🏽‍♂️ Not great at following-instructions ℹ
❌ No fine tuning ℹ
👷🏽‍♂️ Limited agent access ℹ
🔐 Complete data privacy with no data sharing

### Pricing

🆓 Free forever!
API Based
🦾 Model Type: `SQLCoder-34b-instruct` ℹ
🚀 Usage-based pricing using API credits ℹ
✅ Follows-instructions ℹ
❌ No fine tuning ℹ
👷🏽‍♂️ Generalist agent capabilities ℹ
🔐 Metadata shared with our SOC-2 compliant server

### Pricing

🆓 1000 free API credits per month
💰 $0.03 per API credit
- Every 500 tokens of generated SQL = 1 API credit
- Every action taken by an agent = 1 API credit
Locally hosted (Enterprise)
🦾 Model Type: `SQLCoder-34b-instruct` ℹ
🤝 Annual contracts for on-prem deployment ℹ
✅ Follows-instructions ℹ
✅ Fine-tuned model ℹ
👷🏽‍♂️ Specialized agents (incl healthcare and finance) ℹ
🔐 Complete data privacy with no data sharing

### Pricing

💰 Pilots at $5k for 8 weeks
💰 Annual contracts between $60k/yr to $500,000k/yr